@@ -3,12 +3,14 @@ __author__ = 'ninja'
 """ This is a sample piece of code written as part
     of the head first python text """
 
-def print_lol(the_list):
+def print_lol(the_list, level):
     """ this is the function that takes each member of a list
         and checks if the member is a list itself. It recursively prints
         out all the individual members of the nested lists """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item)
+            print_lol(each_item, level + 1)
         else:
-            print(each_item)
\ No newline at end of file
+            for tab_stop in range(level):
+                print("\t", end=' ')
+            print(each_item)
